@@ -1,6 +1,10 @@
 package instrumentation
 
-import "testing"
+import (
+	"testing"
+
+	"github.com/prometheus/client_golang/prometheus"
+)
 
 func Test_preparePath(t *testing.T) {
 	tests := []struct {
@@ -27,3 +31,13 @@ func Test_preparePath(t *testing.T) {
 		})
 	}
 }
+
+func TestMultipleInstrumentedClients(t *testing.T) {
+	reg := prometheus.NewRegistry()
+
+	t.Run("should not panic", func(t *testing.T) {
+		// Following code should run without panicking
+		New("test", reg).InstrumentedRoundTripper()
+		New("test", reg).InstrumentedRoundTripper()
+	})
+}
