@@ -4,11 +4,13 @@ import "time"
 
 // ISO defines the schema of an ISO image.
 type ISO struct {
-	ID          int       `json:"id"`
-	Name        string    `json:"name"`
-	Description string    `json:"description"`
-	Type        string    `json:"type"`
-	Deprecated  time.Time `json:"deprecated"`
+	ID           int64     `json:"id"`
+	Name         string    `json:"name"`
+	Description  string    `json:"description"`
+	Type         string    `json:"type"`
+	Architecture *string   `json:"architecture"`
+	Deprecated   time.Time `json:"deprecated"`
+	DeprecatableResource
 }
 
 // ISOGetResponse defines the schema of the response when retrieving a single ISO.
