@@ -61,7 +61,7 @@ type PricingServerBackup struct {
 
 // PricingServerType defines the schema of pricing information for a server type.
 type PricingServerType struct {
-	ID     int                      `json:"id"`
+	ID     int64                    `json:"id"`
 	Name   string                   `json:"name"`
 	Prices []PricingServerTypePrice `json:"prices"`
 }
@@ -76,7 +76,7 @@ type PricingServerTypePrice struct {
 
 // PricingLoadBalancerType defines the schema of pricing information for a Load Balancer type.
 type PricingLoadBalancerType struct {
-	ID     int                            `json:"id"`
+	ID     int64                          `json:"id"`
 	Name   string                         `json:"name"`
 	Prices []PricingLoadBalancerTypePrice `json:"prices"`
 }
@@ -94,15 +94,16 @@ type PricingGetResponse struct {
 	Pricing Pricing `json:"pricing"`
 }
 
-// PricingPrimaryIPTypePrice defines the schema of pricing information for a primary IP
+// PricingPrimaryIPTypePrice defines the schema of pricing information for a primary IP.
 // type at a datacenter.
 type PricingPrimaryIPTypePrice struct {
-	Datacenter   string `json:"datacenter"`
+	Datacenter   string `json:"datacenter"` // Deprecated: the API does not return pricing for the individual DCs anymore
+	Location     string `json:"location"`
 	PriceHourly  Price  `json:"price_hourly"`
 	PriceMonthly Price  `json:"price_monthly"`
 }
 
-// PricingPrimaryIP define the schema of pricing information for a primary IP at a datacenter
+// PricingPrimaryIP define the schema of pricing information for a primary IP at a datacenter.
 type PricingPrimaryIP struct {
 	Type   string                      `json:"type"`
 	Prices []PricingPrimaryIPTypePrice `json:"prices"`
