@@ -8,7 +8,7 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/hetznercloud/hcloud-go/hcloud/schema"
+	"github.com/hetznercloud/hcloud-go/v2/hcloud/schema"
 )
 
 func TestActionFromSchema(t *testing.T) {
@@ -428,6 +428,7 @@ func TestISOFromSchema(t *testing.T) {
 		"name": "FreeBSD-11.0-RELEASE-amd64-dvd1",
 		"description": "FreeBSD 11.0 x64",
 		"type": "public",
+		"architecture": "x86",
 		"deprecated": "2018-02-28T00:00:00+00:00"
 	}`)
 
@@ -448,6 +449,11 @@ func TestISOFromSchema(t *testing.T) {
 	if iso.Type != ISOTypePublic {
 		t.Errorf("unexpected type: %v", iso.Type)
 	}
+	if iso.Architecture == nil {
+		t.Errorf("unexpected empty architecture")
+	} else if *iso.Architecture != ArchitectureX86 {
+		t.Errorf("unexpected architecture: %s", *iso.Architecture)
+	}
 	if iso.Deprecated.IsZero() {
 		t.Errorf("unexpected value for deprecated: %v", iso.Deprecated)
 	}
@@ -914,6 +920,8 @@ func TestServerTypeFromSchema(t *testing.T) {
 		"disk": 20,
 		"storage_type": "local",
 		"cpu_type": "shared",
+		"architecture": "x86",
+		"deprecation": null,
 		"prices": [
 			{
 				"location": "fsn1",
@@ -959,6 +967,12 @@ func TestServerTypeFromSchema(t *testing.T) {
 	if serverType.CPUType != CPUTypeShared {
 		t.Errorf("unexpected cpu type: %q", serverType.CPUType)
 	}
+	if serverType.Architecture != ArchitectureX86 {
+		t.Errorf("unexpected cpu architecture: %q", serverType.Architecture)
+	}
+	if serverType.Deprecation != nil {
+		t.Errorf("unexpected deprecation: %v", serverType.Deprecation)
+	}
 	if len(serverType.Pricings) != 1 {
 		t.Errorf("unexpected number of pricings: %d", len(serverType.Pricings))
 	} else {
@@ -1139,6 +1153,7 @@ func TestImageFromSchema(t *testing.T) {
 		"bound_to": 1,
 		"os_flavor": "ubuntu",
 		"os_version": "16.04",
+		"architecture": "arm",
 		"rapid_deploy": false,
 		"protection": {
 			"delete": true
@@ -1196,6 +1211,9 @@ func TestImageFromSchema(t *testing.T) {
 	if image.OSFlavor != "ubuntu" {
 		t.Errorf("unexpected OSFlavor: %v", image.OSFlavor)
 	}
+	if image.Architecture != ArchitectureARM {
+		t.Errorf("unexpected architecture: %v", image.Architecture)
+	}
 	if image.RapidDeploy {
 		t.Errorf("unexpected RapidDeploy: %v", image.RapidDeploy)
 	}
@@ -1934,9 +1952,9 @@ func TestCertificateFromSchema(t *testing.T) {
 				Name:           "my website cert",
 				Type:           "uploaded",
 				Certificate:    "-----BEGIN CERTIFICATE-----\n...",
-				Created:        mustParseTime(t, apiTimestampFormat, "2016-01-30T23:50:00+00:00"),
-				NotValidBefore: mustParseTime(t, apiTimestampFormat, "2016-01-30T23:51:00+00:00"),
-				NotValidAfter:  mustParseTime(t, apiTimestampFormat, "2016-01-30T23:55:00+00:00"),
+				Created:        mustParseTime(t, "2016-01-30T23:50:00+00:00"),
+				NotValidBefore: mustParseTime(t, "2016-01-30T23:51:00+00:00"),
+				NotValidAfter:  mustParseTime(t, "2016-01-30T23:55:00+00:00"),
 				DomainNames:    []string{"example.com", "webmail.example.com", "www.example.com"},
 				Fingerprint:    "03:c7:55:9b:2a:d1:04:17:09:f6:d0:7f:18:34:63:d4:3e:5f",
 				UsedBy: []CertificateUsedByRef{
@@ -1978,9 +1996,9 @@ func TestCertificateFromSchema(t *testing.T) {
 				Name:           "managed certificate",
 				Type:           "managed",
 				Certificate:    "-----BEGIN CERTIFICATE-----\n...",
-				Created:        mustParseTime(t, apiTimestampFormat, "2016-01-30T23:50:00+00:00"),
-				NotValidBefore: mustParseTime(t, apiTimestampFormat, "2016-01-30T23:51:00+00:00"),
-				NotValidAfter:  mustParseTime(t, apiTimestampFormat, "2016-01-30T23:55:00+00:00"),
+				Created:        mustParseTime(t, "2016-01-30T23:50:00+00:00"),
+				NotValidBefore: mustParseTime(t, "2016-01-30T23:51:00+00:00"),
+				NotValidAfter:  mustParseTime(t, "2016-01-30T23:55:00+00:00"),
 				DomainNames:    []string{"example.com", "webmail.example.com", "www.example.com"},
 				Fingerprint:    "03:c7:55:9b:2a:d1:04:17:09:f6:d0:7f:18:34:63:d4:3e:5f",
 				Status: &CertificateStatus{
@@ -2044,7 +2062,7 @@ func TestPricingFromSchema(t *testing.T) {
 			{
 				"prices": [
 				{
-					"datacenter": "fsn1-dc8",
+					"location": "fsn1",
 					"price_hourly": {
 					"gross": "1.1900000000000000",
 					"net": "1.0000000000"
@@ -2185,8 +2203,8 @@ func TestPricingFromSchema(t *testing.T) {
 		if len(ip.Pricings) != 1 {
 			t.Errorf("unexpected number of prices: %d", len(ip.Pricings))
 		} else {
-			if ip.Pricings[0].Datacenter != "fsn1-dc8" {
-				t.Errorf("unexpected Datacenter: %v", ip.Pricings[0].Datacenter)
+			if ip.Pricings[0].Location != "fsn1" {
+				t.Errorf("unexpected Location: %v", ip.Pricings[0].Location)
 			}
 			if ip.Pricings[0].Monthly.Net != "1.0000000000" {
 				t.Errorf("unexpected Monthly.Net: %v", ip.Pricings[0].Monthly.Net)
@@ -2346,7 +2364,7 @@ func TestLoadBalancerCreateOptsToSchema(t *testing.T) {
 				Algorithm: &schema.LoadBalancerCreateRequestAlgorithm{
 					Type: string(LoadBalancerAlgorithmTypeRoundRobin),
 				},
-				NetworkZone: String(string(NetworkZoneEUCentral)),
+				NetworkZone: Ptr(string(NetworkZoneEUCentral)),
 			},
 		},
 		"all set": {
@@ -2356,32 +2374,58 @@ func TestLoadBalancerCreateOptsToSchema(t *testing.T) {
 				Algorithm:        &LoadBalancerAlgorithm{Type: LoadBalancerAlgorithmTypeRoundRobin},
 				NetworkZone:      NetworkZoneEUCentral,
 				Labels:           map[string]string{"foo": "bar"},
-				PublicInterface:  Bool(true),
+				PublicInterface:  Ptr(true),
 				Network:          &Network{ID: 3},
 				Services: []LoadBalancerCreateOptsService{
 					{
 						Protocol:        LoadBalancerServiceProtocolHTTP,
-						DestinationPort: Int(80),
-						Proxyprotocol:   Bool(true),
+						DestinationPort: Ptr(80),
+						Proxyprotocol:   Ptr(true),
 						HTTP: &LoadBalancerCreateOptsServiceHTTP{
-							CookieName:     String("keks"),
-							CookieLifetime: Duration(5 * time.Minute),
-							RedirectHTTP:   Bool(true),
-							StickySessions: Bool(true),
+							CookieName:     Ptr("keks"),
+							CookieLifetime: Ptr(5 * time.Minute),
+							RedirectHTTP:   Ptr(true),
+							StickySessions: Ptr(true),
 							Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
 						},
 						HealthCheck: &LoadBalancerCreateOptsServiceHealthCheck{
 							Protocol: LoadBalancerServiceProtocolHTTP,
-							Port:     Int(80),
-							Interval: Duration(5 * time.Second),
-							Timeout:  Duration(1 * time.Second),
-							Retries:  Int(3),
+							Port:     Ptr(80),
+							Interval: Ptr(5 * time.Second),
+							Timeout:  Ptr(1 * time.Second),
+							Retries:  Ptr(3),
 							HTTP: &LoadBalancerCreateOptsServiceHealthCheckHTTP{
-								Domain:      String("example.com"),
-								Path:        String("/health"),
-								Response:    String("ok"),
+								Domain:      Ptr("example.com"),
+								Path:        Ptr("/health"),
+								Response:    Ptr("ok"),
 								StatusCodes: []string{"2??", "3??"},
-								TLS:         Bool(true),
+								TLS:         Ptr(true),
+							},
+						},
+					},
+					{
+						Protocol:        LoadBalancerServiceProtocolHTTP,
+						DestinationPort: Ptr(443),
+						Proxyprotocol:   Ptr(true),
+						HTTP: &LoadBalancerCreateOptsServiceHTTP{
+							CookieName:     Ptr("keks"),
+							CookieLifetime: Ptr(5 * time.Minute),
+							RedirectHTTP:   Ptr(true),
+							StickySessions: Ptr(true),
+							Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
+						},
+						HealthCheck: &LoadBalancerCreateOptsServiceHealthCheck{
+							Protocol: LoadBalancerServiceProtocolHTTP,
+							Port:     Ptr(443),
+							Interval: Ptr(5 * time.Second),
+							Timeout:  Ptr(1 * time.Second),
+							Retries:  Ptr(3),
+							HTTP: &LoadBalancerCreateOptsServiceHealthCheckHTTP{
+								Domain:      Ptr("example.com"),
+								Path:        Ptr("/health"),
+								Response:    Ptr("ok"),
+								StatusCodes: []string{"4??", "5??"},
+								TLS:         Ptr(true),
 							},
 						},
 					},
@@ -2405,37 +2449,63 @@ func TestLoadBalancerCreateOptsToSchema(t *testing.T) {
 				Algorithm: &schema.LoadBalancerCreateRequestAlgorithm{
 					Type: string(LoadBalancerAlgorithmTypeRoundRobin),
 				},
-				NetworkZone: String(string(NetworkZoneEUCentral)),
+				NetworkZone: Ptr(string(NetworkZoneEUCentral)),
 				Labels: func() *map[string]string {
 					labels := map[string]string{"foo": "bar"}
 					return &labels
 				}(),
-				PublicInterface: Bool(true),
-				Network:         Int(3),
+				PublicInterface: Ptr(true),
+				Network:         Ptr(int64(3)),
 				Services: []schema.LoadBalancerCreateRequestService{
 					{
 						Protocol:        string(LoadBalancerServiceProtocolHTTP),
-						DestinationPort: Int(80),
-						Proxyprotocol:   Bool(true),
+						DestinationPort: Ptr(80),
+						Proxyprotocol:   Ptr(true),
 						HTTP: &schema.LoadBalancerCreateRequestServiceHTTP{
-							CookieName:     String("keks"),
-							CookieLifetime: Int(5 * 60),
-							RedirectHTTP:   Bool(true),
-							StickySessions: Bool(true),
-							Certificates:   intSlice([]int{1, 2}),
+							CookieName:     Ptr("keks"),
+							CookieLifetime: Ptr(5 * 60),
+							RedirectHTTP:   Ptr(true),
+							StickySessions: Ptr(true),
+							Certificates:   Ptr([]int64{1, 2}),
 						},
 						HealthCheck: &schema.LoadBalancerCreateRequestServiceHealthCheck{
 							Protocol: string(LoadBalancerServiceProtocolHTTP),
-							Port:     Int(80),
-							Interval: Int(5),
-							Timeout:  Int(1),
-							Retries:  Int(3),
+							Port:     Ptr(80),
+							Interval: Ptr(5),
+							Timeout:  Ptr(1),
+							Retries:  Ptr(3),
 							HTTP: &schema.LoadBalancerCreateRequestServiceHealthCheckHTTP{
-								Domain:      String("example.com"),
-								Path:        String("/health"),
-								Response:    String("ok"),
-								StatusCodes: stringSlice([]string{"2??", "3??"}),
-								TLS:         Bool(true),
+								Domain:      Ptr("example.com"),
+								Path:        Ptr("/health"),
+								Response:    Ptr("ok"),
+								StatusCodes: Ptr([]string{"2??", "3??"}),
+								TLS:         Ptr(true),
+							},
+						},
+					},
+					{
+						Protocol:        string(LoadBalancerServiceProtocolHTTP),
+						DestinationPort: Ptr(443),
+						Proxyprotocol:   Ptr(true),
+						HTTP: &schema.LoadBalancerCreateRequestServiceHTTP{
+							CookieName:     Ptr("keks"),
+							CookieLifetime: Ptr(5 * 60),
+							RedirectHTTP:   Ptr(true),
+							StickySessions: Ptr(true),
+							Certificates:   Ptr([]int64{1, 2}),
+						},
+						HealthCheck: &schema.LoadBalancerCreateRequestServiceHealthCheck{
+							Protocol: string(LoadBalancerServiceProtocolHTTP),
+							Port:     Ptr(443),
+							Interval: Ptr(5),
+							Timeout:  Ptr(1),
+							Retries:  Ptr(3),
+							HTTP: &schema.LoadBalancerCreateRequestServiceHealthCheckHTTP{
+								Domain:      Ptr("example.com"),
+								Path:        Ptr("/health"),
+								Response:    Ptr("ok"),
+								StatusCodes: Ptr([]string{"4??", "5??"}),
+								TLS:         Ptr(true),
 							},
 						},
 					},
@@ -2484,53 +2554,53 @@ func TestLoadBalancerAddServiceOptsToSchema(t *testing.T) {
 		"all set": {
 			Opts: LoadBalancerAddServiceOpts{
 				Protocol:        LoadBalancerServiceProtocolHTTP,
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &LoadBalancerAddServiceOptsHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Duration(5 * time.Minute),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * time.Minute),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
 					Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
 				},
 				HealthCheck: &LoadBalancerAddServiceOptsHealthCheck{
 					Protocol: LoadBalancerServiceProtocolHTTP,
-					Port:     Int(80),
-					Interval: Duration(5 * time.Second),
-					Timeout:  Duration(1 * time.Second),
-					Retries:  Int(3),
+					Port:     Ptr(80),
+					Interval: Ptr(5 * time.Second),
+					Timeout:  Ptr(1 * time.Second),
+					Retries:  Ptr(3),
 					HTTP: &LoadBalancerAddServiceOptsHealthCheckHTTP{
-						Domain:      String("example.com"),
-						Path:        String("/health"),
-						Response:    String("ok"),
+						Domain:      Ptr("example.com"),
+						Path:        Ptr("/health"),
+						Response:    Ptr("ok"),
 						StatusCodes: []string{"2??", "3??"},
-						TLS:         Bool(true),
+						TLS:         Ptr(true),
 					},
 				},
 			},
 			Request: schema.LoadBalancerActionAddServiceRequest{
 				Protocol:        string(LoadBalancerServiceProtocolHTTP),
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &schema.LoadBalancerActionAddServiceRequestHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Int(5 * 60),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
-					Certificates:   intSlice([]int{1, 2}),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * 60),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
+					Certificates:   Ptr([]int64{1, 2}),
 				},
 				HealthCheck: &schema.LoadBalancerActionAddServiceRequestHealthCheck{
 					Protocol: string(LoadBalancerServiceProtocolHTTP),
-					Port:     Int(80),
-					Interval: Int(5),
-					Timeout:  Int(1),
-					Retries:  Int(3),
+					Port:     Ptr(80),
+					Interval: Ptr(5),
+					Timeout:  Ptr(1),
+					Retries:  Ptr(3),
 					HTTP: &schema.LoadBalancerActionAddServiceRequestHealthCheckHTTP{
-						Domain:      String("example.com"),
-						Path:        String("/health"),
-						Response:    String("ok"),
-						StatusCodes: stringSlice([]string{"2??", "3??"}),
-						TLS:         Bool(true),
+						Domain:      Ptr("example.com"),
+						Path:        Ptr("/health"),
+						Response:    Ptr("ok"),
+						StatusCodes: Ptr([]string{"2??", "3??"}),
+						TLS:         Ptr(true),
 					},
 				},
 			},
@@ -2538,26 +2608,26 @@ func TestLoadBalancerAddServiceOptsToSchema(t *testing.T) {
 		"no health check": {
 			Opts: LoadBalancerAddServiceOpts{
 				Protocol:        LoadBalancerServiceProtocolHTTP,
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &LoadBalancerAddServiceOptsHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Duration(5 * time.Minute),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * time.Minute),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
 					Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
 				},
 			},
 			Request: schema.LoadBalancerActionAddServiceRequest{
 				Protocol:        string(LoadBalancerServiceProtocolHTTP),
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &schema.LoadBalancerActionAddServiceRequestHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Int(5 * 60),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
-					Certificates:   intSlice([]int{1, 2}),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * 60),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
+					Certificates:   Ptr([]int64{1, 2}),
 				},
 				HealthCheck: nil,
 			},
@@ -2586,53 +2656,53 @@ func TestLoadBalancerUpdateServiceOptsToSchema(t *testing.T) {
 		"all set": {
 			Opts: LoadBalancerUpdateServiceOpts{
 				Protocol:        LoadBalancerServiceProtocolHTTP,
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &LoadBalancerUpdateServiceOptsHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Duration(5 * time.Minute),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * time.Minute),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
 					Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
 				},
 				HealthCheck: &LoadBalancerUpdateServiceOptsHealthCheck{
 					Protocol: LoadBalancerServiceProtocolHTTP,
-					Port:     Int(80),
-					Interval: Duration(5 * time.Second),
-					Timeout:  Duration(1 * time.Second),
-					Retries:  Int(3),
+					Port:     Ptr(80),
+					Interval: Ptr(5 * time.Second),
+					Timeout:  Ptr(1 * time.Second),
+					Retries:  Ptr(3),
 					HTTP: &LoadBalancerUpdateServiceOptsHealthCheckHTTP{
-						Domain:      String("example.com"),
-						Path:        String("/health"),
-						Response:    String("ok"),
+						Domain:      Ptr("example.com"),
+						Path:        Ptr("/health"),
+						Response:    Ptr("ok"),
 						StatusCodes: []string{"2??", "3??"},
-						TLS:         Bool(true),
+						TLS:         Ptr(true),
 					},
 				},
 			},
 			Request: schema.LoadBalancerActionUpdateServiceRequest{
-				Protocol:        String(string(LoadBalancerServiceProtocolHTTP)),
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				Protocol:        Ptr(string(LoadBalancerServiceProtocolHTTP)),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &schema.LoadBalancerActionUpdateServiceRequestHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Int(5 * 60),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
-					Certificates:   intSlice([]int{1, 2}),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * 60),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
+					Certificates:   Ptr([]int64{1, 2}),
 				},
 				HealthCheck: &schema.LoadBalancerActionUpdateServiceRequestHealthCheck{
-					Protocol: String(string(LoadBalancerServiceProtocolHTTP)),
-					Port:     Int(80),
-					Interval: Int(5),
-					Timeout:  Int(1),
-					Retries:  Int(3),
+					Protocol: Ptr(string(LoadBalancerServiceProtocolHTTP)),
+					Port:     Ptr(80),
+					Interval: Ptr(5),
+					Timeout:  Ptr(1),
+					Retries:  Ptr(3),
 					HTTP: &schema.LoadBalancerActionUpdateServiceRequestHealthCheckHTTP{
-						Domain:      String("example.com"),
-						Path:        String("/health"),
-						Response:    String("ok"),
-						StatusCodes: stringSlice([]string{"2??", "3??"}),
-						TLS:         Bool(true),
+						Domain:      Ptr("example.com"),
+						Path:        Ptr("/health"),
+						Response:    Ptr("ok"),
+						StatusCodes: Ptr([]string{"2??", "3??"}),
+						TLS:         Ptr(true),
 					},
 				},
 			},
@@ -2640,26 +2710,26 @@ func TestLoadBalancerUpdateServiceOptsToSchema(t *testing.T) {
 		"no health check": {
 			Opts: LoadBalancerUpdateServiceOpts{
 				Protocol:        LoadBalancerServiceProtocolHTTP,
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &LoadBalancerUpdateServiceOptsHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Duration(5 * time.Minute),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * time.Minute),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
 					Certificates:   []*Certificate{{ID: 1}, {ID: 2}},
 				},
 			},
 			Request: schema.LoadBalancerActionUpdateServiceRequest{
-				Protocol:        String(string(LoadBalancerServiceProtocolHTTP)),
-				DestinationPort: Int(80),
-				Proxyprotocol:   Bool(true),
+				Protocol:        Ptr(string(LoadBalancerServiceProtocolHTTP)),
+				DestinationPort: Ptr(80),
+				Proxyprotocol:   Ptr(true),
 				HTTP: &schema.LoadBalancerActionUpdateServiceRequestHTTP{
-					CookieName:     String("keks"),
-					CookieLifetime: Int(5 * 60),
-					RedirectHTTP:   Bool(true),
-					StickySessions: Bool(true),
-					Certificates:   intSlice([]int{1, 2}),
+					CookieName:     Ptr("keks"),
+					CookieLifetime: Ptr(5 * 60),
+					RedirectHTTP:   Ptr(true),
+					StickySessions: Ptr(true),
+					Certificates:   Ptr([]int64{1, 2}),
 				},
 				HealthCheck: nil,
 			},
@@ -2688,8 +2758,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.ServerGetMetricsResponse {
 				var resp schema.ServerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.ServerTimeSeriesVals{
 					"cpu": {
 						Values: []interface{}{"some value"},
@@ -2705,8 +2775,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.ServerGetMetricsResponse {
 				var resp schema.ServerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.ServerTimeSeriesVals{
 					"cpu": {
 						Values: []interface{}{
@@ -2724,8 +2794,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.ServerGetMetricsResponse {
 				var resp schema.ServerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.ServerTimeSeriesVals{
 					"cpu": {
 						Values: []interface{}{
@@ -2743,8 +2813,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.ServerGetMetricsResponse {
 				var resp schema.ServerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.ServerTimeSeriesVals{
 					"cpu": {
 						Values: []interface{}{
@@ -2762,8 +2832,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.ServerGetMetricsResponse {
 				var resp schema.ServerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.ServerTimeSeriesVals{
 					"cpu": {
 						Values: []interface{}{
@@ -2800,8 +2870,8 @@ func TestServerMetricsFromSchema(t *testing.T) {
 				return &resp
 			},
 			expected: &ServerMetrics{
-				Start: mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z"),
-				End:   mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z"),
+				Start: mustParseTime(t, "2017-01-01T00:00:00Z"),
+				End:   mustParseTime(t, "2017-01-01T23:00:00Z"),
 				TimeSeries: map[string][]ServerMetricsValue{
 					"cpu": {
 						{Timestamp: 1435781470.622, Value: "42"},
@@ -2858,8 +2928,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.LoadBalancerGetMetricsResponse {
 				var resp schema.LoadBalancerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.LoadBalancerTimeSeriesVals{
 					"open_connections": {
 						Values: []interface{}{"some value"},
@@ -2875,8 +2945,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.LoadBalancerGetMetricsResponse {
 				var resp schema.LoadBalancerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.LoadBalancerTimeSeriesVals{
 					"open_connections": {
 						Values: []interface{}{
@@ -2894,8 +2964,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.LoadBalancerGetMetricsResponse {
 				var resp schema.LoadBalancerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.LoadBalancerTimeSeriesVals{
 					"open_connections": {
 						Values: []interface{}{
@@ -2913,8 +2983,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.LoadBalancerGetMetricsResponse {
 				var resp schema.LoadBalancerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.LoadBalancerTimeSeriesVals{
 					"open_connections": {
 						Values: []interface{}{
@@ -2932,8 +3002,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 			respFn: func() *schema.LoadBalancerGetMetricsResponse {
 				var resp schema.LoadBalancerGetMetricsResponse
 
-				resp.Metrics.Start = mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z")
-				resp.Metrics.End = mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z")
+				resp.Metrics.Start = mustParseTime(t, "2017-01-01T00:00:00Z")
+				resp.Metrics.End = mustParseTime(t, "2017-01-01T23:00:00Z")
 				resp.Metrics.TimeSeries = map[string]schema.LoadBalancerTimeSeriesVals{
 					"open_connections": {
 						Values: []interface{}{
@@ -2970,8 +3040,8 @@ func TestLoadBalancerMetricsFromSchema(t *testing.T) {
 				return &resp
 			},
 			expected: &LoadBalancerMetrics{
-				Start: mustParseTime(t, time.RFC3339, "2017-01-01T00:00:00Z"),
-				End:   mustParseTime(t, time.RFC3339, "2017-01-01T23:00:00Z"),
+				Start: mustParseTime(t, "2017-01-01T00:00:00Z"),
+				End:   mustParseTime(t, "2017-01-01T23:00:00Z"),
 				TimeSeries: map[string][]LoadBalancerMetricsValue{
 					"open_connections": {
 						{Timestamp: 1435781470.622, Value: "42"},
@@ -3155,3 +3225,43 @@ func TestPlacementGroupFromSchema(t *testing.T) {
 		t.Errorf("unexpected Type %s", placementGroup.Type)
 	}
 }
+
+func TestDeprecationFromSchema(t *testing.T) {
+	t.Run("Deprecated Resource", func(t *testing.T) {
+		data := []byte(`{
+			"deprecation": {
+				"announced": "2023-06-01T00:00:00+00:00",
+				"unavailable_after": "2023-09-01T00:00:00+00:00"
+			}
+		}`)
+
+		var d schema.DeprecatableResource
+		if err := json.Unmarshal(data, &d); err != nil {
+			t.Fatal(err)
+		}
+		deprecationInfo := DeprecationFromSchema(d.Deprecation)
+		if deprecationInfo == nil {
+			t.Fatal("unexpected nil DeprecationInfo")
+		}
+		if deprecationInfo.Announced != mustParseTime(t, "2023-06-01T00:00:00+00:00") {
+			t.Errorf("unexpected anounce time %s", deprecationInfo.Announced)
+		}
+		if deprecationInfo.UnavailableAfter != mustParseTime(t, "2023-09-01T00:00:00+00:00") {
+			t.Errorf("unexpected unavailable after time %s", deprecationInfo.UnavailableAfter)
+		}
+	})
+
+	t.Run("Not-deprecated Resource", func(t *testing.T) {
+		data := []byte(`{
+			"deprecation": null
+		}`)
+		var d schema.DeprecatableResource
+		if err := json.Unmarshal(data, &d); err != nil {
+			t.Fatal(err)
+		}
+		deprecationInfo := DeprecationFromSchema(d.Deprecation)
+		if deprecationInfo != nil {
+			t.Fatal("unexpected non-nil DeprecationInfo", deprecationInfo)
+		}
+	})
+}
